==> magic3_1.8.0_b15_src.tar.gz: magic3/widgets/admin_main/include/container/admin_mainBrowseBaseWidgetContainer.php <==
<?php
/**
 * コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2009 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: admin_mainBrowseBaseWidgetContainer.php 2159 2009-07-25 13:40:53Z fishbone $
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');

class admin_mainBrowseBaseWidgetContainer extends BaseWidgetContainer
{
	const HELP_KEY_RESBROWSE = 'resbrowse';// リソースブラウズ
	const HELP_KEY_FILEBROWSE = 'filebrowse';// ファイルブラウズ
	const DEFAULT_TOP_PAGE = 'resbrowse';		// デフォルトのトップ画面
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @return								なし
	 */
	function _postAssign($request, &$param)
	{
		// 表示画面を決定
		$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
		if (empty($task)) $task = self::DEFAULT_TOP_PAGE;
		
		// パンくずリストを作成
		switch ($task){
			case 'resbrowse':	// リソースブラウズ
				$linkList = '&nbsp;&nbsp;&gt;&gt;&nbsp;&nbsp;リソースブラウズ';
				break;
			case 'filebrowse':	// ファイルブラウズ
				$linkList = '&nbsp;&nbsp;&gt;&gt;&nbsp;&nbsp;ファイルアップロード';
				break;
		}
				
		// ####### 上段メニューの作成 #######
		$menuText = '<div id="configmenu-upper">' . M3_NL;
		$menuText .= '<ul>' . M3_NL;
		
		$current = '';
		$link = $this->gEnv->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $this->gEnv->getCurrentWidgetId();
				
		// ### リソースブラウズ ###
		$current = '';
		$link = $this->gEnv->getDefaultAdminUrl() . '?' . 'task=resbrowse';
		if ($task == 'resbrowse'){
			$current = 'id="current"';
		}
		// ヘルプを作成
		$helpText = $this->gHelp->getHelpText(self::HELP_KEY_RESBROWSE);
		$menuText .= '<li ' . $current . '><a href="'. $link .'"><span ' . $helpText . '>リソースブラウズ</span></a></li>' . M3_NL;
		
		// ### ファイルアップロード ###
		$current = '';
		$link = $this->gEnv->getDefaultAdminUrl() . '?' . 'task=filebrowse';
		if ($task == 'filebrowse'){
			$current = 'id="current"';
		}
		// ヘルプを作成
		$helpText = $this->gHelp->getHelpText(self::HELP_KEY_FILEBROWSE);
		$menuText .= '<li ' . $current . '><a href="'. $link .'"><span ' . $helpText . '>ファイルアップロード</span></a></li>' . M3_NL;
		
		// 上段メニュー終了
		$menuText .= '</ul>' . M3_NL;
		$menuText .= '</div>' . M3_NL;
		
		// 作成データの埋め込み
		$linkList = '<div id="configmenu-top"><label>' . 'ファイルブラウザー' . $linkList . '</div>';
		$outputText .= '<table width="90%"><tr><td>' . $linkList . $menuText . '</td></tr></table>' . M3_NL;
		$this->tmpl->addVar("_widget", "menu_items", $outputText);
	}
}
?>

==> magic3_1.8.5_src.tar.gz: magic3/widgets/admin_main/include/container/admin_mainBrowseBaseWidgetContainer.php <==
<?php
/**
 * コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2009 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: admin_mainBrowseBaseWidgetContainer.php 2235 2009-08-19 02:00:26Z fishbone $
 * @link       http://www.magic3.org
 */
//require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');

class admin_mainBrowseBaseWidgetContainer extends admin_mainBaseWidgetContainer
{
	const HELP_KEY_RESBROWSE = 'resbrowse';// リソースブラウズ
	const HELP_KEY_FILEBROWSE = 'filebrowse';// ファイルブラウズ
	const DEFAULT_TOP_PAGE = 'resbrowse';		// デフォルトのトップ画面
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @return								なし
	 */
	function _postAssign($request, &$param)
	{
		// 表示画面を決定
		$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
		if (empty($task)) $task = self::DEFAULT_TOP_PAGE;
		
		// パンくずリストを作成
		switch ($task){
			case 'resbrowse':	// リソースブラウズ
				$linkList = '&nbsp;&nbsp;&gt;&gt;&nbsp;&nbsp;リソースブラウズ';
				break;
			case 'filebrowse':	// ファイルブラウズ
				$linkList = '&nbsp;&nbsp;&gt;&gt;&nbsp;&nbsp;ファイルアップロード';
				break;
		}
				
		// ####### 上段メニューの作成 #######
		$menuText = '<div id="configmenu-upper">' . M3_NL;
		$menuText .= '<ul>' . M3_NL;
		
		$current = '';
		$link = $this->gEnv->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $this->gEnv->getCurrentWidgetId();
				
		// ### リソースブラウズ ###
		$current = '';
		$link = $this->gEnv->getDefaultAdminUrl() . '?' . 'task=resbrowse';
		if ($task == 'resbrowse'){
			$current = 'id="current"';
		}
		// ヘルプを作成
		$helpText = $this->gHelp->getHelpText(self::HELP_KEY_RESBROWSE);
		$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span ' . $helpText . '>リソースブラウズ</span></a></li>' . M3_NL;
		
		// ### ファイルアップロード ###
		$current = '';
		$link = $this->gEnv->getDefaultAdminUrl() . '?' . 'task=filebrowse';
		if ($task == 'filebrowse'){
			$current = 'id="current"';
		}
		// ヘルプを作成
		$helpText = $this->gHelp->getHelpText(self::HELP_KEY_FILEBROWSE);
		$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span ' . $helpText . '>ファイルアップロード</span></a></li>' . M3_NL;
		
		// 上段メニュー終了
		$menuText .= '</ul>' . M3_NL;
		$menuText .= '</div>' . M3_NL;
		
		// 作成データの埋め込み
		$linkList = '<div id="configmenu-top"><label>' . 'ファイルブラウザー' . $linkList . '</div>';
		$outputText .= '<table width="90%"><tr><td>' . $linkList . $menuText . '</td></tr></table>' . M3_NL;
		$this->tmpl->addVar("_widget", "menu_items", $outputText);
	}
}
?>
